@@ -35,8 +35,20 @@ from google.cloud.artifactregistry_v1.types.apt_artifact import (
 from google.cloud.artifactregistry_v1.types.artifact import (
     DockerImage,
     GetDockerImageRequest,
+    GetMavenArtifactRequest,
+    GetNpmPackageRequest,
+    GetPythonPackageRequest,
     ListDockerImagesRequest,
     ListDockerImagesResponse,
+    ListMavenArtifactsRequest,
+    ListMavenArtifactsResponse,
+    ListNpmPackagesRequest,
+    ListNpmPackagesResponse,
+    ListPythonPackagesRequest,
+    ListPythonPackagesResponse,
+    MavenArtifact,
+    NpmPackage,
+    PythonPackage,
 )
 from google.cloud.artifactregistry_v1.types.file import (
     File,
@@ -77,6 +89,7 @@ from google.cloud.artifactregistry_v1.types.tag import (
     UpdateTagRequest,
 )
 from google.cloud.artifactregistry_v1.types.version import (
+    BatchDeleteVersionsMetadata,
     DeleteVersionRequest,
     GetVersionRequest,
     ListVersionsRequest,
@@ -84,6 +97,11 @@ from google.cloud.artifactregistry_v1.types.version import (
     Version,
     VersionView,
 )
+from google.cloud.artifactregistry_v1.types.vpcsc_config import (
+    GetVPCSCConfigRequest,
+    UpdateVPCSCConfigRequest,
+    VPCSCConfig,
+)
 from google.cloud.artifactregistry_v1.types.yum_artifact import (
     ImportYumArtifactsErrorInfo,
     ImportYumArtifactsGcsSource,
@@ -104,8 +122,20 @@ __all__ = (
     "ImportAptArtifactsResponse",
     "DockerImage",
     "GetDockerImageRequest",
+    "GetMavenArtifactRequest",
+    "GetNpmPackageRequest",
+    "GetPythonPackageRequest",
     "ListDockerImagesRequest",
     "ListDockerImagesResponse",
+    "ListMavenArtifactsRequest",
+    "ListMavenArtifactsResponse",
+    "ListNpmPackagesRequest",
+    "ListNpmPackagesResponse",
+    "ListPythonPackagesRequest",
+    "ListPythonPackagesResponse",
+    "MavenArtifact",
+    "NpmPackage",
+    "PythonPackage",
     "File",
     "GetFileRequest",
     "Hash",
@@ -134,12 +164,16 @@ __all__ = (
     "ListTagsResponse",
     "Tag",
     "UpdateTagRequest",
+    "BatchDeleteVersionsMetadata",
     "DeleteVersionRequest",
     "GetVersionRequest",
     "ListVersionsRequest",
     "ListVersionsResponse",
     "Version",
     "VersionView",
+    "GetVPCSCConfigRequest",
+    "UpdateVPCSCConfigRequest",
+    "VPCSCConfig",
     "ImportYumArtifactsErrorInfo",
     "ImportYumArtifactsGcsSource",
     "ImportYumArtifactsMetadata",
